@@ -1,6 +1,6 @@
 package Net::DNS::RR::AFSDB;
 #
-# $Id: AFSDB.pm 388 2005-06-22 10:06:05Z olaf $
+# $Id: AFSDB.pm 718 2008-02-26 21:49:20Z olaf $
 #
 use strict;
 
@@ -11,7 +11,7 @@ BEGIN {
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 388 $)[1];
+$VERSION = (qw$LastChangedRevision: 718 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -32,8 +32,8 @@ sub new_from_string {
 
 	if ($string && ($string =~ /^(\d+)\s+(\S+)$/)) {
 		$self->{"subtype"}  = $1;
-		$self->{"hostname"} = $2;
-		$self->{"hostname"} =~ s/\.+$//;;
+		$self->{"hostname"} = Net::DNS::stripdot($2);
+
 	}
 
 	return bless $self, $class;
@@ -61,6 +61,18 @@ sub rr_rdata {
 }
 
 
+sub _normalize_dnames {
+	my $self=shift;
+	$self->_normalize_ownername();
+
+	foreach my $attribute ( qw ( hostname ) ){
+		$self->{$attribute}=Net::DNS::stripdot($self->{$attribute}) if defined $self->{$attribute};
+	}
+
+}
+
+
+
 
 sub _canonicalRdata {
     # rdata contains a compressed domainname... we should not have that.
@@ -68,7 +80,7 @@ sub _canonicalRdata {
 	my $rdata;
 	if (exists $self->{"subtype"}) {
 	    $rdata .= pack("n", $self->{"subtype"});
-	    $rdata .=  $self->_name2wire($self->{"hostname"});
+	    $rdata .=  $self->_name2wire(lc($self->{"hostname"}));
 	}
 	return $rdata;
 }
