@@ -1,12 +1,16 @@
+#
+# $Id: NS.pm 718 2008-02-26 21:49:20Z olaf $
+#
 package Net::DNS::RR::NS;
-#
-# $Id: NS.pm 102 2004-08-12 05:16:06Z ctriv $
-#
+
 use strict;
+BEGIN { 
+    eval { require bytes; }
+} 
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$LastChangedRevision: 102 $)[1];
+$VERSION = (qw$LastChangedRevision: 718 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -22,8 +26,7 @@ sub new_from_string {
 	my ($class, $self, $string) = @_;
 
 	if ($string) {
-		$string =~ s/\.+$//;
-		$self->{"nsdname"} = $string;
+		$self->{"nsdname"} = Net::DNS::stripdot($string);
 	}
 
 	return bless $self, $class;
@@ -48,11 +51,18 @@ sub rr_rdata {
 
 
 
+sub _normalize_dnames {
+	my $self=shift;
+	$self->_normalize_ownername();
+	$self->{'nsdname'}=Net::DNS::stripdot($self->{'nsdname'}) if defined $self->{'nsdname'};
+}
+
+
 sub _canonicalRdata {
     # rdata contains a compressed domainname... we should not have that.
 	my ($self) = @_;
 	my $rdata;
-	$rdata=$self->_name2wire($self->{"nsdname"});
+	$rdata= $self->_name2wire(lc($self->{"nsdname"}));
 	return $rdata;
 }
 
@@ -78,7 +88,7 @@ Class for DNS Name Server (NS) resource records.
 
     print "nsdname = ", $rr->nsdname, "\n";
 
-Returns the domain name of the nameserver.
+Returns the name of the nameserver.
 
 =head1 COPYRIGHT
 
@@ -86,6 +96,10 @@ Copyright (c) 1997-2002 Michael Fuhr.
 
 Portions Copyright (c) 2002-2004 Chris Reinhardt.
 
+Portions Copyright (c) 2005 O.M, Kolkman, RIPE NCC.
+
+Portions Copyright (c) 2005-2006 O.M, Kolkman, NLnet Labs.
+
 All rights reserved.  This program is free software; you may redistribute
 it and/or modify it under the same terms as Perl itself.
 
